#
# spec file for package python-cachelib
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-cachelib
Version:        0.10.2
Release:        150600.1.2
Summary:        A collection of cache libraries in the same API interface
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/pallets-eco/cachelib
Source:         https://files.pythonhosted.org/packages/source/c/cachelib/cachelib-%{version}.tar.gz
# PATCH-FIX-UPSTREAM skip-failing-tests.patch gh#pallets-eco/cachelib#228 mcepl@suse.com
# skip failing tests
Patch0:         skip-failing-tests.patch
BuildRequires:  %{python_module pylibmc}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  redis
Recommends:     python-pylibmc
BuildArch:      noarch
# SECTION test
BuildRequires:  %{python_module pluggy}
BuildRequires:  %{python_module pylibmc}
BuildRequires:  %{python_module pyparsing}
BuildRequires:  %{python_module pytest-xprocess}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module urllib3 < 2}
BuildRequires:  memcached
# /SECTION
%python_subpackages

%description
A collection of cache libraries in the same API interface.

%prep
%autosetup -p1 -n cachelib-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# set up working directory
export BASETEMP=$(mktemp -d -t cachelib_test.XXXXXX)
trap "rm -rf ${BASETEMP}" EXIT
# Allow finding memcached
export PATH="%{_sbindir}/:$PATH"
PYTEST_ADDOPTS="--capture=tee-sys --tb=short --basetemp=${BASETEMP}"
PYTEST_ADDOPTS="$PYTEST_ADDOPTS --ignore=tests/test_redis_cache.py"
PYTEST_ADDOPTS="$PYTEST_ADDOPTS --ignore=tests/test_memcached_cache.py"
export PYTEST_ADDOPTS
%pytest -rs -k "not network"

%files %{python_files}
%license LICENSE.rst
%doc README.rst
%{python_sitelib}/cachelib
%{python_sitelib}/cachelib-%{version}*-info

%changelog
* Fri Dec 29 2023 alarrosa@suse.com
- Remove BuildRequires for python-redis and python-boto3 which are
  not really required nor even used when building the package
  (I also checked that the same number of tests are
  passed/skipped/deselected with and without those packages).
- Remove the Recommendation for python-redis, since that is only
  used if the user of cachelib wants to use a Redis key-value store
  as a cache backend and in that case it should be clear that they
  need the python-redis package installed. This two changes simplify
  the dependencies a lot which is specially useful in SLE.
* Sun Jun 11 2023 ecsos@opensuse.org
- Add %%{?sle15_python_module_pythons}
* Tue May 23 2023 steven.kowalik@suse.com
- Restrict urllib3 to < 2, due to boto.
* Tue Feb  7 2023 mcepl@suse.com
- Update to 0.10.2:
  - Fix logging pollution due to DynamoDB logging handler
  - Improve error message when FileSystemCache methods are called
    with non-str keys.
  - Added DynamoDb as a cache backend
- Add skip-failing-tests.patch to skip failing tests requiring
  network access (gh#pallets-eco/cachelib#228).
* Tue Aug 23 2022 jayvdb@gmail.com
- Activate test suite
- Update to v0.9.0
  * Add separate internal read/write clients to RedisCache to
    improve compatibility with flask-caching.
  * Fix bug where cache entries would expire immediately when
    RedisCache.add was called without timeout.
  * Improve FileSystemCache.set compatibility with Windows systems.
- from v0.8.0
  * Remove deprecated RedisCache.load_object and RedisCache.dump_object.
- from v0.7.0
  * FileSystemCache now stores universal expiration timestamps
    using python's struct module.
  * Drop support for Python 3.6.
- from v0.6.0
  * A custom hash_method may now be provided to FileSystemCache
    for hashing keys.
  * Fix PermissionError issue with FileSystemCache on Windows.
- from v0.5.0
  * Cache types now have configurable serializers.
- from v0.4.1
  * Fix break in RedisCache when a host object was passed in
    RedisCache.host instead of a string.
- from v0.4.0
  * All cache types now implement BaseCache interface both in
    behavior and method return types.
  * Add type information for static typing tools.
  * FileNotFound exceptions will not be logged anymore in
    FileSystemCache methods in order to avoid polluting
    application log files.
- from v0.3.0
  * Optimize FileSystemCache pruning.
  * Fix a bug in FileSystemCache where entries would not be
    removed when the total was over the threshold, and the entry
    count would be lost.
  * FileSystemCache logs system-related exceptions.
  * Removal of expired entries in FileSystemCache is only triggered
    if the number of entries is over the threshhold when calling set.
    get has still return None and False respectively for expired
    entries, but will not remove the files. All removals happen at
    pruning time or explicitly with clear and delete.
- from v0.2.0
  * Support for Python 2 has been dropped.
  * Only Python 3.6 and above are supported.
  * Fix FileSystemCache.set incorrectly considering value overrides
    on existing keys as new cache entries.
  * SimpleCache and FileSystemCache first remove expired entries,
    followed by older entries, when cleaning up.
  * Fix problem where file count was not being updated in
    FileSystemCache.get and FileSystemCache.has after removals.
  * When attempting to access non-existent entries with Memcached,
    these will now be initialized with a given value delta.
- from v0.1.1
  * Fix FileSystemCache on Windows.
* Fri Dec  6 2019 erico.mendonca@suse.com
- Initial version.
